Retrieves the full metadata record for a single dataset.
Value
A one-row tibble of dataset metadata (nested fields
such as contact or creator are list-columns), or the raw list when
.raw = TRUE.
Retrieves the full metadata record for a single dataset.
A one-row tibble of dataset metadata (nested fields
such as contact or creator are list-columns), or the raw list when
.raw = TRUE.