Skip to contents

ChecklistBank exposes a family of parsers that interpret free text into controlled values (ranks, countries, dates, licenses, nomenclatural codes, taxonomic status, and more). This returns the names of all value parsers usable with clb_parse(). The scientific-name parser is wrapped separately by clb_parse_name().

Usage

clb_parsers()

Value

A character vector of parser type names.

Examples

if (FALSE) { # \dontrun{
clb_parsers()
} # }