Returns subtree metrics for a taxon: tree depth, child and species counts, and a by-rank breakdown of descendants.
Value
A one-row tibble of metrics. Map fields such as
taxaByRankCount are returned as list-columns.
Returns subtree metrics for a taxon: tree depth, child and species counts, and a by-rank breakdown of descendants.
A one-row tibble of metrics. Map fields such as
taxaByRankCount are returned as list-columns.