The Catalogue of Life is published as a managed project (dataset key 3)
from which immutable releases are derived. There are two cadences
(monthly and annual) and two flavours (a base release and an extended
release XR, which merges additional external data). This helper returns
the dataset identifier (an alias such as "3LXR" or "COL25") you can pass
to any dataset = argument in this package.
Usage
clb_col_release(cadence = c("monthly", "annual"), extended = FALSE)Value
A length-one character vector with the release alias, or NA (with
a warning) when the requested release has not been published yet – as is
currently the case for the annual extended release.
Details
The monthly releases have stable magic aliases that always point at the most recent one:
"3LR"– latest monthly base release"3LXR"– latest monthly extended release
Annual releases use a COL<YY> alias (e.g. "COL25", and "COL25 XR" for
the extended variant). The latest one is discovered from the list of all
releases of project 3.
See also
clb_col_releases() for the full list of releases.