Atomises one or more scientific names into their nomenclatural components (genus, epithets, rank, authorship, ...) using the GBIF name parser exposed by ChecklistBank.
Value
A tibble with one row per input name and columns
such as scientificName, authorship, rank, genus,
specificEpithet, type and parsed. Nested fields (e.g.
combinationAuthorship) are returned as list-columns.
Examples
if (FALSE) { # \dontrun{
clb_parse_name("Abies alba Mill.")
clb_parse_name(c("Panthera leo (Linnaeus, 1758)", "Bellis perennis L."))
} # }